aboutsummaryrefslogtreecommitdiffstats
path: root/activemodel/lib
diff options
context:
space:
mode:
authorJoshua Peek <josh@joshpeek.com>2009-10-07 09:24:51 -0500
committerJoshua Peek <josh@joshpeek.com>2009-10-07 09:24:51 -0500
commitff56f3d5e1c69b923625f20a80f25c2eee3bbb35 (patch)
treec9c05a6dfa6c6a85a397fa167a16d1371dfc1014 /activemodel/lib
parent4df96338ede62da8ae8c188de5454b4b6b186ff8 (diff)
downloadrails-ff56f3d5e1c69b923625f20a80f25c2eee3bbb35.tar.gz
rails-ff56f3d5e1c69b923625f20a80f25c2eee3bbb35.tar.bz2
rails-ff56f3d5e1c69b923625f20a80f25c2eee3bbb35.zip
Rewrite ActiveModel::Lint as a simple TU mixin
Diffstat (limited to 'activemodel/lib')
-rw-r--r--activemodel/lib/active_model/lint.rb78
1 files changed, 30 insertions, 48 deletions
diff --git a/activemodel/lib/active_model/lint.rb b/activemodel/lib/active_model/lint.rb
index ceaa29dc8c..1c2347adbf 100644
--- a/activemodel/lib/active_model/lint.rb
+++ b/activemodel/lib/active_model/lint.rb
@@ -1,6 +1,6 @@
# You can test whether an object is compliant with the ActiveModel API by
# calling ActiveModel::Lint.test(object). It will emit a Test::Unit
# output that tells you whether your object is fully compliant, or if not,
# which aspects of the API are not implemented.
#
# These tests do not attempt to determine the semantic correctness of the
@@ -12,36 +12,15 @@
# call to to_model. It is perfectly fine for to_model to return self.
module ActiveModel
module Lint
- def self.test(object, verbosity = 2, output = STDOUT)
- require "test/unit"
- require "test/unit/ui/console/testrunner"
-
- test_class = Class.new(::Test::Unit::TestCase) do
- include Test
-
- define_method(:setup) do
- assert object.respond_to?(:to_model), "The object should respond_to :to_model"
- @object = object.to_model
- super
- end
- end
-
- ::Test::Unit::UI::Console::TestRunner.new(test_class, verbosity, output).start
- end
-
- module Test
- def assert_boolean(name, result)
- assert result == true || result == false, "#{name} should be a boolean"
- end
-
+ module Tests
# valid?
# ------
#
# Returns a boolean that specifies whether the object is in a valid or invalid
# state.
def test_valid?
- assert @object.respond_to?(:valid?), "The model should respond to valid?"
- assert_boolean "valid?", @object.valid?
+ assert model.respond_to?(:valid?), "The model should respond to valid?"
+ assert_boolean model.valid?, "valid?"
end
# new_record?
@@ -53,13 +32,13 @@ module ActiveModel
# collection. If it is persisted, a form for the object will put PUTed to the
# URL for the object.
def test_new_record?
- assert @object.respond_to?(:new_record?), "The model should respond to new_record?"
- assert_boolean "new_record?", @object.new_record?
+ assert model.respond_to?(:new_record?), "The model should respond to new_record?"
+ assert_boolean model.new_record?, "new_record?"
end
def test_destroyed?
- assert @object.respond_to?(:destroyed?), "The model should respond to destroyed?"
- assert_boolean "destroyed?", @object.destroyed?
+ assert model.respond_to?(:destroyed?), "The model should respond to destroyed?"
+ assert_boolean model.destroyed?, "destroyed?"
end
# errors
@@ -67,29 +46,32 @@ module ActiveModel
#
# Returns an object that has :[] and :full_messages defined on it. See below
# for more details.
- def setup
- assert @object.respond_to?(:errors), "The model should respond to errors"
- @errors = @object.errors
+
+ # Returns an Array of Strings that are the errors for the attribute in
+ # question. If localization is used, the Strings should be localized
+ # for the current locale. If no error is present, this method should
+ # return an empty Array.
+ def test_errors_aref
+ assert model.respond_to?(:errors), "The model should respond to errors"
+ assert model.errors[:hello].is_a?(Array), "errors#[] should return an Array"
end
- # This module tests the #errors object
- module Errors
- # Returns an Array of Strings that are the errors for the attribute in
- # question. If localization is used, the Strings should be localized
- # for the current locale. If no error is present, this method should
- # return an empty Array.
- def test_errors_aref
- assert @errors[:hello].is_a?(Array), "errors#[] should return an Array"
- end
+ # Returns an Array of all error messages for the object. Each message
+ # should contain information about the field, if applicable.
+ def test_errors_full_messages
+ assert model.respond_to?(:errors), "The model should respond to errors"
+ assert model.errors.full_messages.is_a?(Array), "errors#full_messages should return an Array"
+ end
- # Returns an Array of all error messages for the object. Each message
- # should contain information about the field, if applicable.
- def test_errors_full_messages
- assert @errors.full_messages.is_a?(Array), "errors#full_messages should return an Array"
+ private
+ def model
+ assert @model.respond_to?(:to_model), "The object should respond_to to_model"
+ @model.to_model
end
- end
- include Errors
+ def assert_boolean(result, name)
+ assert result == true || result == false, "#{name} should be a boolean"
+ end
end
end
end
@@ -1,6 +1,6 @@
# You can test whether an object is compliant with the ActiveModel API by
-# calling ActiveModel::Lint.test(object). It will emit a Test::Unit
-# output that tells you whether your object is fully compliant, or if not,
+# including ActiveModel::Lint::Tests in your TestCase. It will included
+# tests that tell you whether your object is fully compliant, or if not,
# which aspects of the API are not implemented.
#